sequencetools.sum_consecutive_elements_by_sign
==============================================

.. autofunction:: abjad.tools.sequencetools.sum_consecutive_elements_by_sign.sum_consecutive_elements_by_sign
